@@ -184,6 +184,12 @@ Type::Type(const std::string& name, const eckit::Value& settings) :
                     vals.push_back(vv);
                 }
                 ASSERT(s.contains("context"));
+                if (s.contains("warn")) {
+                    std::string warn = s["warn"];
+                    if (!warn.empty()) {
+                        // warnings_.insert(warn);
+                    }
+                }
                 sets_.emplace(Context::parseContext(s["context"]), vals);
             }
         }
@@ -194,6 +200,18 @@ Type::Type(const std::string& name, const eckit::Value& settings) :
             for (size_t i = 0; i < unsets.size(); i++) {
                 eckit::Value u = unsets[i];
                 ASSERT(u.contains("context"));
+                if (u.contains("warn")) {
+                    std::string warn = u["warn"];
+                    if (!warn.empty()) {
+                        // warnings_.insert(warn);
+                    }
+                }
+                if (u.contains("error")) {
+                    std::string error = u["error"];
+                    if (!error.empty()) {
+                        // warnings_.insert(error);
+                    }
+                }
                 unsets_.insert(Context::parseContext(u["context"]));
             }
         }
@@ -263,31 +281,13 @@ std::ostream& operator<<(std::ostream& s, const Type& x) {
     return s;
 }
 
-
-std::string Type::tidy(const MarsExpandContext& ctx, const std::string& value, const MarsRequest& request) const {
+std::string Type::tidy(const std::string& value, const MarsExpandContext& ctx, const MarsRequest& request) const {
     std::string result = value;
     expand(ctx, result, request);
     return result;
 }
 
-std::string Type::tidy(const std::string& value, const MarsRequest& request) const {
-    DummyContext ctx;
-    return tidy(ctx, value, request);
-}
-
-std::vector<std::string> Type::tidy(const std::vector<std::string>& values, const MarsRequest& request) const {
-    DummyContext ctx;
-
-    std::vector<std::string> result;
-    result.reserve(values.size());
-
-    std::transform(values.begin(), values.end(), std::back_inserter(result),
-                   [this, ctx, request](const std::string& s) { return this->tidy(ctx, s, request); });
-
-    return result;
-}
-
-bool Type::expand(const MarsExpandContext&, std::string& value, const MarsRequest& request) const {
+bool Type::expand(const MarsExpandContext&, std::string& value, const MarsRequest&) const {
     std::ostringstream oss;
     oss << *this << ":  expand not implemented (" << value << ")";
     throw eckit::SeriousBug(oss.str());
@@ -300,27 +300,32 @@ void Type::expand(const MarsExpandContext& ctx, std::vector<std::string>& values
     }
 
     std::vector<std::string> newvals;
-
     std::set<std::string> seen;
 
-    for (const std::string& val : values) {
+    for (std::string& val : values) {
         std::string value = val;
         if (!expand(ctx, value, request)) {
             std::ostringstream oss;
             oss << *this << ": cannot expand '" << val << "'" << ctx;
             throw eckit::UserError(oss.str());
         }
-
-        if (!duplicates_) {
-            if (seen.find(value) != seen.end()) {
+        if (hasGroups()) {
+            const std::vector<std::string>& gg = group(value);
+            for (const auto& v : gg) {
+                if (seen.find(v) == seen.end()) {
+                    seen.insert(v);
+                    newvals.push_back(v);
+                }
+            }
+        }
+        else {
+            if (!duplicates_ && seen.find(value) != seen.end()) {
                 std::ostringstream oss;
-                oss << *this << ": duplicated value '" << val << "'" << ctx;
+                oss << *this << ": duplicated value '" << value << "'" << ctx;
                 throw eckit::UserError(oss.str());
             }
-            seen.insert(value);
+            newvals.push_back(value);
         }
-
-        newvals.push_back(value);
     }
 
     std::swap(newvals, values);
